﻿/* 
 * MWin GameDev - http://mwin.pl
 * 
 * Plik stanowi część kursu Unity3d
 * 
 * Unity3d QuickTip #26 - Drzewko Umiejętności Postaci
 * Autor: Marek Winiarski (http://mwin.pl)
 * 
 */

using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class SkillTree : MonoBehaviour 
{
	private PlayerStats ps;
	private bool showTree;
	private List<MySkill> listOfSkills;

	
	void Start () 
	{
		ps = gameObject.GetComponent<PlayerStats> ();
		showTree = false;
		listOfSkills = new List<MySkill>();

		MySkill HP1 = new MySkill (new Rect (200, 20, 50, 40), "HP I", 100, "maxHP", 120);
		MySkill HP2 = new MySkill (new Rect (200, 80, 50, 40), "HP II", 200, "maxHP", 140);
		MySkill HP3 = new MySkill (new Rect (200, 140, 50, 40), "HP III", 200, "maxHP", 160);
		HP2.addRequirement (HP1);
		HP3.addRequirement (HP2);

		MySkill SP1 = new MySkill (new Rect (300, 20, 50, 40), "SP I", 100, "superPunch", 1);
		MySkill SP2 = new MySkill (new Rect (300, 80, 50, 40), "SP II", 100, "superPunch", 2);
		SP2.addRequirement (SP1);

		MySkill QK = new MySkill (new Rect (400, 20, 50, 40), "QK", 100, "quickKill", 1);
		MySkill DM = new MySkill (new Rect (350, 140, 50, 40), "DM", 100, "deathMachine", 1);
		DM.addRequirement (QK);
		DM.addRequirement (SP2);

		listOfSkills.Add (HP1);
		listOfSkills.Add (HP2);
		listOfSkills.Add (HP3);
		listOfSkills.Add (SP1);
		listOfSkills.Add (SP2);
		listOfSkills.Add (DM);
		listOfSkills.Add (QK);
	}
	
	void Update () 
	{
		if (Input.GetKeyDown (KeyCode.C)) {
			showTree = !showTree;
		}
	}

	void OnGUI()
	{
		if (showTree) {
			for(int i = 0 ; i < listOfSkills.Count ; i++) {
				MySkill skill = listOfSkills[i];
				if(skill.isActive) {
					GUI.color = skill.btnOn;
				} else {
					GUI.color = skill.btnOff;
				}

				if (GUI.Button (skill.position, skill.label)) {
					if(skill.isAvailable() && (ps.playerGold >= skill.goldCost) && !skill.isActive) {
						ps.playerGold -= skill.goldCost;
						ps.changePlayerStat(skill.statToChange, skill.statValue);
						skill.isActive = true;
					}
				}
			}
		}
	}
}
